//+------------------------------------------------------------------+
//|                                                   Xm7FibAlert.mq4|
//|                                           Xmess7 Productions 2008|
//+------------------------------------------------------------------+
//|
//|Simple alert setup for when price reaches a predetermined FIB line.
//|This is based on TRO's the big picture approach. Except, I use the H1/D1 to place fibs.
//|Then I zoom in to the 5 min or 15 min and wait for an entry.  The entry consistes of simply
//|waiting for price to cross a fib line.  I take the same direction as price crossed the FIB.
//|
//| This code will send an alarm to an email, text message, or the regular window(with sound) 
//| when Price is close to a FIB level and H1 is in same direction.  The FIB levels is defined
//| in the INPUTS but the user.
//|
//| One thing to note the ALERT will not be sent MUTLIPLE times.  The code implements a "waiting"
//| count and certain condition need to be met.  I am still working on it but at the least
//| you get the warning alot less times than what is seen on other indicators.  
//|
//|  CREDTIS:
//|   Fib levels are automatically plotted. Functions and code was derived from 
//|   #SpudFibo.mq4  (http://www.forexfactory.com/showthread.php?t=30109)
//|
//|   The code for H1 openline  was provided by Shane Less
//|   tradingmail@bigpond.com      SP_openline.mq4
//|
//|   Money Managment method is provided by Dragon33.
//|   Aproximate risk is 2.5% of account.  
//|   Value of PIP is calculated by taking Accoubt balance by 400   
//+------------------------------------------------------------------+
 
#property copyright "Copyright  2008, Xmess7 Productions."
#property indicator_chart_window

extern bool SignalMail = false;
extern bool SignalAlert = true;
extern string INSTRUCT1  = "Enter Price value at the FIB level above and below current Price" ;
extern double FIB_Above_Price = 0;
extern double FIB_Below_Price = 0;
extern string INSTRUCT2  = "Enter the number of pips that the ALARM will go off" ;
extern int Alarm_to_FIB = 25;
extern string H1_Pivot_Note = "<- Set true following to see Open H1 line and/or Pivot of previous candle->";
extern bool ShowH1Open = false;
extern bool ShowPrevPivot = false;
extern string	ColorNote		= "<--- Fibonacci colors --->";
extern color	UpperFiboColor	= Navy;
extern color	MainFiboColor	= RoyalBlue;
extern color	LowerFiboColor = DodgerBlue;
extern double  account_balance = 0.0;


// Variables from FIB indicator  #SpudFibo.mq4
int		TimeFrame		= PERIOD_D1;
int		OpenTime			= 0;
int		TimeZone			= 0;
double   HiPrice, LoPrice, Range;
datetime StartTime, EndTime;
string	TimeFrameStr;		// Used to label High and Low
int		FirstHour,		// First hour that is used for the range calculation in server time
			LastHour;	// Last hour that is included in the range calculation in server time

int init()
  {
  //reset comment field
  Comment(" ");
  if (FIB_Above_Price == 0 && FIB_Below_Price == 0 && GlobalVariableCheck(Symbol() + "FIB_Above")) {
      FIB_Above_Price = GlobalVariableGet(Symbol() + "FIB_Above");
      FIB_Below_Price = GlobalVariableGet( Symbol() + "FIB_Below");
     }
     
    // Calculate hours and time for FIB props.  Code from #SpudFibo.mq4
   int timeShift=0;  //This can shift when and u can use it to determine which hour to start the FIBs
   FirstHour = OpenTime%24;
	if(FirstHour>0)	LastHour = FirstHour-1;
	else					LastHour = 23;
	LastHour += 24+timeShift;	LastHour %=24;
	FirstHour+= 24+timeShift;	FirstHour%=24;  
 }

int deinit()
  {
   ObjectDelete("FiboUp");
   ObjectDelete("FiboDn");
   ObjectDelete("FiboIn");
  }

int start() {

   double Buy_Delta, Sell_Delta,AlarmTotalShow, PIP_Value;
   bool NearCrossUP =false, NearCrossDN=false, CandleUP=false;
   int spread = MarketInfo(Symbol(),MODE_SPREAD), PIPS;
  
   // Draw Fibs on chart.  Currently only using the Previous D1 as the high and low for Fib placement
   FIBS();

   //Show a horizontal line for the OPEN HOUR (thanks to Shanes indicator - SP_openline.mq4
   if (ShowH1Open) ShowOpenHour();
   if (ShowPrevPivot) ShowPivot();  //Show pivot of previous candle
  
   //Check to see if user has inputed Upper and Lower Fib Levels  
   if (FIB_Below_Price == 0 || FIB_Above_Price == 0) {
      Comment("You did not enter a FIB Level, Go EDIT INDICATOR AND add a FIB level above and below current price","\n","Indicator is deactivated");
      return(0);
      } else {
      // Lets set these as global variables 
      GlobalVariableSet(Symbol() + "FIB_Above", FIB_Above_Price); 
      GlobalVariableSet(Symbol() + "FIB_Below", FIB_Below_Price); 
   }

  if (FIB_Below_Price > FIB_Above_Price) { // OOPS User inputed fibs in reverse.  Lets fix that.
    Buy_Delta = FIB_Above_Price;  //Temporary use of Buy_Delta variable for swap
    FIB_Below_Price = FIB_Above_Price;
    FIB_Above_Price = FIB_Below_Price;
  }

  //I used the Bars array to get ask and bid instead of the regular function
  //This allows the program to work in the stategy tester
  double Open0 = Open[0];
  double Bid0 = Close[0];
  double Ask0 = Close[0] + spread * Point;

  Sell_Delta = (Bid0 - FIB_Below_Price)/Point;
  Buy_Delta = (FIB_Above_Price - Ask0)/Point;

  //Set PIPS value to whichever is negative.  The logic is inverted here cause
  //1st we are trying to get distance from price to the FIB levels
  //But when Price crosses a FIB it becomes negative

  if (Buy_Delta < Alarm_to_FIB) NearCrossUP = true;
  if (Sell_Delta < Alarm_to_FIB) NearCrossDN = true;
  if (Buy_Delta <= 0) PIPS = Buy_Delta*(-1);
  if (Sell_Delta <= 0) PIPS = Sell_Delta*(-1);

  //Determine if candle is bullish or bearish
   if (Bid0 - Open0 >= 0) CandleUP = true;

  //Calcuate PIP value using DRAGON33 MM
  if (account_balance == 0.0) account_balance = AccountBalance();
  PIP_Value = MathFloor(account_balance/400);
  if(PIP_Value <= 0) PIP_Value = 0.1;
  
  //Display some info to USER
  Comment("PIPS till BUY ",Buy_Delta,"   PIPS till SELL  ", Sell_Delta,"            ",                         
  "DRAGON33 MONEY MANAGEMENT recommended PIP value: $",PIP_Value,"  This is based on a balance of $",account_balance,"\n",
  "Spread for ",Symbol()," ", spread,"       Current Bid ", Bid0,"  Current Ask ",Ask0,"\n",
  "FibAbove ",FIB_Above_Price,"          FibBelow ",FIB_Below_Price,"\n");

//-----------------------------------------------------------
// This is where the actual entry logic occurs
//-------------------------------------------------------------

 // First lets see if the PIPS have exceeded the FIBS by about 30pips.
 // If so tell user that the need to re-enter the new Upper and Lower FIB levels
   if (PIPS > 30) {
    Comment("You need to re-enter the UPPER and LOWER FIB LEVELS","\n",
    "Got to the INPUT of indicator en reenter the new inforamtion for the UPPER and LOWER FIBs","\n",
    "If you are still in a trade or already in PROFIT ignore this message :), you can do it later." );
    //Reset the Global Variable
    NearCrossUP = false;
    NearCrossDN = false;
    GlobalVariableSet(Symbol() + "AlarmTotalShow",0);
    }
    
   //Alerts and Messages
   if (CandleUP && NearCrossUP) {
     Comment("Spread is ",spread,"   ENTER BUY @ ",FIB_Above_Price - spread * Point,"    PIPS ",PIPS);
      if( GlobalVariableGet(Symbol() + "AlarmTotalShow") == 0 && Buy_Delta > (Alarm_to_FIB - 15)) {           
            if (SignalAlert) Alert("Price is near FIB.  Buy Alert for ",Symbol()," @ ",FIB_Above_Price); 
            if (SignalMail) SendMail("Buy Alert","FIB Cross UP for "+ Symbol() + " @ " + FIB_Above_Price);
            }
     AlarmTotalShow = GlobalVariableGet(Symbol() + "AlarmTotalShow") + 1; 
   }
  if (!CandleUP && NearCrossDN) {
    Comment("Spread is ",spread,"    ENTER SELL @ ",FIB_Below_Price + spread * Point,"   PIPS ", PIPS); 
      if(GlobalVariableGet(Symbol() + "AlarmTotalShow") == 0 && Sell_Delta > Alarm_to_FIB - 15) {     
            if (SignalAlert) Alert("Price is near FIB.  Sell Alert for", Symbol()," @ ",FIB_Below_Price); 
            if (SignalMail) SendMail("Sell Alert","FIB Cross DN for "+ Symbol() + " @ " + FIB_Below_Price);
            }
     AlarmTotalShow = GlobalVariableGet(Symbol() + "AlarmTotalShow") + 1; 
  }

// Incremented AlarmTotalShow by 1. This global variable will prevent MT4 from displaying 
// a alert several times.  This can be annoying :)     
   GlobalVariableSet(Symbol() + "AlarmTotalShow",AlarmTotalShow);            
   
   return(0);
  }


//+------------------------------------------------------------------+
//| FIBS()  Code Credit: #SpudFibo.mq4
//| http://www.forexfactory.com/showthread.php?t=30109
//+------------------------------------------------------------------+
void FIBS() {
	if(TimeFrame!=PERIOD_D1 || (OpenTime==0 && TimeZone==0))
//	Use daily, weekly, whatever candles
	{
		int shift	= iBarShift(NULL,TimeFrame,Time[0]) + 1;	// yesterday
		HiPrice		= iHigh(NULL,TimeFrame,shift);
		LoPrice		= iLow (NULL,TimeFrame,shift);
		StartTime	= iTime(NULL,TimeFrame,shift);
		EndTime		= StartTime+TimeFrame*60;

		if(TimeFrame==PERIOD_D1 && TimeDayOfWeek(StartTime)==0/*Sunday*/)
		{//Add fridays high and low
			HiPrice = MathMax(HiPrice,iHigh(NULL,PERIOD_D1,shift+1));
			LoPrice = MathMin(LoPrice,iLow(NULL,PERIOD_D1,shift+1));
			StartTime = iTime(NULL,PERIOD_D1,shift+1);
		}
	}
	else
//	Use hourly candles
	{
	//----
	//	find last candle of the period
		shift = 1;
		while(TimeHour(iTime(NULL,PERIOD_H1,shift)) != LastHour)
			shift++;
	//----
	//	find first candle of the period
		int startShift = shift;
		while(TimeHour(iTime(NULL,PERIOD_H1,startShift)) != FirstHour
		||TimeDayOfWeek(iTime(NULL,PERIOD_H1,startShift))==0/*Sunday*/)
			startShift++;
		while(TimeHour(iTime(NULL,PERIOD_H1,startShift)) == FirstHour)
			startShift++;
		startShift--;

	//----
	//	get the highest high and lowest low of the period
		HiPrice		= iHigh(NULL,PERIOD_H1,iHighest(NULL,PERIOD_H1,MODE_HIGH,startShift-shift+1,shift));
		LoPrice		= iLow (NULL,PERIOD_H1,iLowest (NULL,PERIOD_H1,MODE_LOW, startShift-shift+1,shift));
		StartTime	= iTime(NULL,PERIOD_H1,startShift);
		EndTime		= iTime(NULL,PERIOD_H1,shift);
	}

	Range = HiPrice-LoPrice;
	DrawFibo();

	return(0);
}

//+------------------------------------------------------------------+
//| Draw Fibo  Code Credit: #SpudFibo.mq4
//| http://www.forexfactory.com/showthread.php?t=30109
//+------------------------------------------------------------------+
int DrawFibo() {

	if(ObjectFind("FiboUp") == -1)
		ObjectCreate("FiboUp",OBJ_FIBO,0,StartTime,HiPrice+Range,StartTime,HiPrice);
	else
	{
		ObjectSet("FiboUp",OBJPROP_TIME2, StartTime);
		ObjectSet("FiboUp",OBJPROP_TIME1, StartTime);
		ObjectSet("FiboUp",OBJPROP_PRICE1,HiPrice+Range);
		ObjectSet("FiboUp",OBJPROP_PRICE2,HiPrice);
	}
   ObjectSet("FiboUp",OBJPROP_LEVELCOLOR,UpperFiboColor);
   ObjectSet("FiboUp",OBJPROP_FIBOLEVELS,7);
   ObjectSet("FiboUp",OBJPROP_FIRSTLEVEL+0,0.0);	ObjectSetFiboDescription("FiboUp",0,TimeFrameStr+" HIGH (100.0%) -  %$"); 
   ObjectSet("FiboUp",OBJPROP_FIRSTLEVEL+1,0.236);	ObjectSetFiboDescription("FiboUp",1,"(123.6%) -  %$"); 
   ObjectSet("FiboUp",OBJPROP_FIRSTLEVEL+2,0.382);	ObjectSetFiboDescription("FiboUp",2,"(138.2%) -  %$"); 
   ObjectSet("FiboUp",OBJPROP_FIRSTLEVEL+3,0.500);	ObjectSetFiboDescription("FiboUp",3,"(150.0%) -  %$"); 
   ObjectSet("FiboUp",OBJPROP_FIRSTLEVEL+4,0.618);	ObjectSetFiboDescription("FiboUp",4,"(161.8%) -  %$"); 
   ObjectSet("FiboUp",OBJPROP_FIRSTLEVEL+5,0.764);	ObjectSetFiboDescription("FiboUp",5,"(176.4%) -  %$"); 
   ObjectSet("FiboUp",OBJPROP_FIRSTLEVEL+6,1.000);	ObjectSetFiboDescription("FiboUp",6,"(200.0%) -  %$"); 
   ObjectSet("FiboUp",OBJPROP_RAY,true);
   ObjectSet("FiboUp",OBJPROP_BACK,true);

//----
	if(ObjectFind("FiboDn") == -1)
		ObjectCreate("FiboDn",OBJ_FIBO,0,StartTime,LoPrice-Range,StartTime,LoPrice);
	else
	{
		ObjectSet("FiboDn",OBJPROP_TIME2, StartTime);
		ObjectSet("FiboDn",OBJPROP_TIME1, StartTime);
		ObjectSet("FiboDn",OBJPROP_PRICE1,LoPrice-Range);
		ObjectSet("FiboDn",OBJPROP_PRICE2,LoPrice);
	}
   ObjectSet("FiboDn",OBJPROP_LEVELCOLOR,LowerFiboColor); 
   ObjectSet("FiboDn",OBJPROP_FIBOLEVELS,7);
   ObjectSet("FiboDn",OBJPROP_FIRSTLEVEL+0,0.0);	ObjectSetFiboDescription("FiboDn",0,TimeFrameStr+" LOW (0.0%) -  %$"); 
   ObjectSet("FiboDn",OBJPROP_FIRSTLEVEL+1,0.236);	ObjectSetFiboDescription("FiboDn",1,"(-23.6%) -  %$"); 
   ObjectSet("FiboDn",OBJPROP_FIRSTLEVEL+2,0.382);	ObjectSetFiboDescription("FiboDn",2,"(-38.2%) -  %$"); 
   ObjectSet("FiboDn",OBJPROP_FIRSTLEVEL+3,0.500);	ObjectSetFiboDescription("FiboDn",3,"(-50.0%) -  %$"); 
   ObjectSet("FiboDn",OBJPROP_FIRSTLEVEL+4,0.618);	ObjectSetFiboDescription("FiboDn",4,"(-61.8%) -  %$"); 
   ObjectSet("FiboDn",OBJPROP_FIRSTLEVEL+5,0.764);	ObjectSetFiboDescription("FiboDn",5,"(-76.4%) -  %$"); 
   ObjectSet("FiboDn",OBJPROP_FIRSTLEVEL+6,1.000);	ObjectSetFiboDescription("FiboDn",6,"(-100.0%) -  %$"); 
   ObjectSet("FiboDn",OBJPROP_RAY,true);
   ObjectSet("FiboDn",OBJPROP_BACK,true);

//----
	if(ObjectFind("FiboIn") == -1)
		ObjectCreate("FiboIn",OBJ_FIBO,0,StartTime,HiPrice,EndTime,LoPrice);
	else
	{
		ObjectSet("FiboIn",OBJPROP_TIME1, StartTime);
		ObjectSet("FiboIn",OBJPROP_TIME2, StartTime+TimeFrame*60);
		ObjectSet("FiboIn",OBJPROP_PRICE1,HiPrice);
		ObjectSet("FiboIn",OBJPROP_PRICE2,LoPrice);
	}
  	ObjectSet("FiboIn",OBJPROP_LEVELCOLOR,MainFiboColor); 
  	ObjectSet("FiboIn",OBJPROP_FIBOLEVELS,5);
  	ObjectSet("FiboIn",OBJPROP_FIRSTLEVEL+0,0.236);	ObjectSetFiboDescription("FiboIn",0,"(23.6"+"\x25"+") -  %$"); 
  	ObjectSet("FiboIn",OBJPROP_FIRSTLEVEL+1,0.382);	ObjectSetFiboDescription("FiboIn",1,"(38.2) -  %$"); 
  	ObjectSet("FiboIn",OBJPROP_FIRSTLEVEL+2,0.500);	ObjectSetFiboDescription("FiboIn",2,"(50.0) -  %$"); 
  	ObjectSet("FiboIn",OBJPROP_FIRSTLEVEL+3,0.618);	ObjectSetFiboDescription("FiboIn",3,"(61.8) -  %$"); 
  	ObjectSet("FiboIn",OBJPROP_FIRSTLEVEL+4,0.764);	ObjectSetFiboDescription("FiboIn",4,"(76.4) -  %$"); 
  	ObjectSet("FiboIn",OBJPROP_RAY,true);
  	ObjectSet("FiboIn",OBJPROP_BACK,true);
}



// function to Draw OPen HOUR line with LABEL 
//  I used Shanes SP_openline.mq4 code in this function.  Only difference is that I use
//  Bars instead of the function to determine the H1 open price.  This allows indicator
//  To work in the strategy tester.
void ShowOpenHour() {

 color  linecolor    = LightSkyBlue;
 int    width        = 2;
 int    style        = 0;
 bool   label        = True;
 int    labelsize    = 2;
 color Line.Color=Orange;
 int Line.Style=1;
 int Line.Width=1;
 int BarsBack=0;

if (TimeMinute(Time[0]) > 0) BarsBack = TimeMinute(Time[0])/Period() ;

   ObjectDelete("OpenH1PriceLevel");
   ObjectDelete("H1_Open_Price"); 
  
   // Horizonal H1 line
   ObjectCreate("OpenH1PriceLevel",OBJ_TREND,0,Time[BarsBack],Open[BarsBack],TimeCurrent(),Open[BarsBack]);
   ObjectSet("OpenH1PriceLevel",OBJPROP_RAY,False);
   ObjectSet("OpenH1PriceLevel",OBJPROP_COLOR,linecolor);
   ObjectSet("OpenH1PriceLevel",OBJPROP_STYLE,style);
   ObjectSet("OpenH1PriceLevel",OBJPROP_WIDTH,width);
   
   // Label
   ObjectCreate("H1_Open_Price",OBJ_ARROW,0,TimeCurrent(),Open[BarsBack]);
   ObjectSet("H1_Open_Price",OBJPROP_ARROWCODE,SYMBOL_RIGHTPRICE);
   ObjectSet("H1_Open_Price",OBJPROP_COLOR,linecolor);
   ObjectSet("H1_Open_Price",OBJPROP_WIDTH,labelsize);
   
return(0);
}

//This Function draws a pivot arrow
void ShowPivot() {

   double pivot = (High[1] +  Low[1] + Close[1])/3;
     
   ObjectDelete("Pivot_Arrow");
   ObjectCreate("Pivot_Arrow",OBJ_ARROW,0,Time[0],pivot);
   ObjectSet("Pivot_Arrow",OBJPROP_ARROWCODE,216);
   ObjectSet("Pivot_Arrow",OBJPROP_COLOR,Sienna);
   ObjectSet("Pivot_Arrow",OBJPROP_STYLE,STYLE_SOLID);
   ObjectSet("Pivot_Arrow",OBJPROP_WIDTH,1);
   ObjectSet("Pivot_Arrow",OBJPROP_BACK,false);

   return(0);
  }
  
  /*
  
  Folks:   
Hope everyone is doing well. I wrote this attached indicator and want to share it with you guys.    
This is the approach I use and it has provided good results. It includes code and methods from:   
TRO's TheBigPicture   Dragon33 MM   SudoFIB   SP_openline (Shane Lee)      
As I have mentioned in the thread.   
Basically plot FIB lines on the D1 or H1 timeframes and then just wait at the 5min or 15min timeframe to make an entry.   The entry is determined by SEEING in which direction Price crosses the FIB.      

I decided to create this indicator so that instead of being at the computer I would just receive a text message that an opportunity has appeared.  Then I just scoot over to any machine and proceed to wait only the neccessary amount of time.      

This indicator will automatically plot the FIB lines. All you do is enter the FIB levels you see above and below the current price level. Then just wait for the indicator to issue an alert. You can set it up to send email, text message, or simple see that alarm with the sound and etc etc.      The alerts are triggered when price gets within 25pips of any fib. I also included the H1 bias (I don't really use it but to keep folks on the safe side I added it). You will see a message that indicates at which price you enter the trade. That price is a spread away from the FIB level. You can enter there or as Price is crossing the FIB level.      

This indicator, to a certain extent, is 70% of my approach (check my previous posts ). The other 30% has to do with observations and in general experience. For example you can include the Buzzard or the Break OUT strategies to determine if you will take the entry. But in general when Price crosses a FIB it does with some vengeance.      Anyhow, please try it out. Hope it provides another weapon that you can use to drain them banks. Let me know if you need more info or help.      Happy Draining      

PS:For you programmers I tried to put as much comments in the code so you can follow it. If you have any suggestions or ideas please go ahead... lets make it better.   Attached Files   

*/